<?

 /*************************************************************************************
 * Filename: blog.php
 *
 * This file is part of the Blog JAS plugin.
 * Copyright 2003-2016 by Matthijs Schuurman
 *
 * The Blog JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/blog/
 *************************************************************************************/


 require_once($_path["include"]."data.php");
 require_once($_path["format"]."template.php");
 require_once($_path["plugins"]."lister/lister.php");

 class Plugin_blog extends Plugin_lister
 {
  function main()
  {
   global $_benchmark, $_blogCommentSubmitted, $_config;

   if(!$this->config)
    return false;

   $this->commentError=false;

   //only submit in blog/item mode to ensure error is set to correct template
   if($this->config["listtype"]!="Blog"&&$this->config["listtype"]!="Item")
    return true;

   //ensure comments are only submitted once
   if($_blogCommentSubmitted)
    return true;

   //comment submit
   $_blogCommentSubmitted=true;
   if($this->commentText=request("comment"))
   {
    if($_benchmark) $_benchmark->start("Submit comment");

    $d=Data::cache("blog_comments", "add", "item");

    if($_config->userAnonymous())
    {
     $d->addField("captcha", "captcha", "form", "", 0, 5, "", "Captcha");
     $d->setRequestValue("captcha");
    }

    $d->setValue("text", $this->commentText);
    $this->commentEntry=$d->getValue("blogentry");

    if(!$d->submit())
     $this->commentError=$d->e->show();

    if($_benchmark) $_benchmark->stop("Submit comment");
   }

   return true;
  }

  function _getData()
  {
   global $_benchmark;

   if(!$this->config)
    return false;

   if($_benchmark) $_benchmark->start("Data object");

   if($this->config["listtype"]=="Blog"||$this->config["listtype"]=="Item")
   {
    $d=Data::cache("blog_entries", "view", "all");
    $d->clearValues();

    //set show fields so lister->cache takes these in to account when checking cache
    $d->setShowFields("comments", "blog_tagsmapping");
    $d->getReferenceData("comments")->setShowFields("text");
    $d->getReferenceData("blog_tagsmapping")->getReferenceData("blog_tags")->setShowFields("tag");

    if($this->config["listcatnr"])
     $d->setValue("catnr", $this->config["listcatnr"]);

    $d->setValue("show_total", $this->config["listitems"]);

    if($this->config["pagebrowser"]) //only show "next page" if page browser is active
    {
     if(request("show_page"))
      $d->setRequestValue("show_page", request("show_page"));
     if(request("show_from"))
      $d->setRequestValue("show_from", request("show_from"));
    }

    $d->sortOrder("date-", "blog_tagsmapping"); //also ensure tags are correctly sorted
    $d->getReferenceData("blog_tagsmapping")->sortOrder("blog_tags");

    if(request("search")) //index search
    {
     $d->setAction("search");
     $d->setExtra("index");

     $d->setValue("search", request("search"));
     $d->sortOrder("fulltext-");

     if(!$d->getValue("show_total")) //ensure limit is set
      $d->setValue("show_total", 100);

     if(!$d->get(false, true)||!$d->getValue("show_count")) //no results, try normal search
     {
      $d->setExtra("full");

      $d->unsetValue("fulltext");
      $d->unsetValue("show_count");

      $d->setValue("search", request("search"));
      $d->sortOrder("date-");
     }
     else //results
      $d->setValue("search", request("search")); //re-set search
    }
    else if($arg=request("p", 1))
    {
     if(preg_match("/^\d{4}-\d{2}-\d{2}$/", $arg)) //date
     {
      $arg=strtotime($arg);
      $d->setValue("date", date($d->field["date"]["format"][$d->dataformat]["datetimeformat"], $arg), 0);
      $d->setValue("date", date($d->field["date"]["format"][$d->dataformat]["datetimeformat"], $arg+86400), 1);
      $d->setOperator("date", ">=", 0);
      $d->setOperator("date", "<", 1);
      $d->setOperant("date", "AND", 0);
      $d->setOperant("date", "AND", 1);
     }
     else if(preg_match("/^\d+$/", $arg)) //entry
     {
      $d->setValue("nr", $arg);

      $this->config["listtype"]="Item";
     }
     else //tag
      $d->setValue("tags", $arg);
    }

    //display published or unpublished if user has edit rights
    $d->setValue("r", "00000000001", 2);
    $d->setOperator("r", "&", 2);
    $d->setOperant("r", "OR", 2);
    $d->setValue("published", true, 2);
   }
   else if($this->config["listtype"]=="Latest posts"||$this->config["listtype"]=="Latest comments") //Latest posts/comments
   {
    if($this->config["listtype"]=="Latest posts")
    {
     $d=Data::cache("blog_entries", "view", "all");
     $d->sortOrder("date-");
    }
    else //comments
    {
     $d=Data::cache("blog_comments", "view", "all");
     $d->sortOrder("updated-");
    }

    $d->clearValues();

    if($this->config["listcatnr"])
     $d->setValue("catnr", $this->config["listcatnr"]);

    //display published or unpublished if user has edit rights
    if($this->config["listtype"]=="Latest posts")
    {
     $d->setValue("r", "00000000001", 2);
     $d->setOperator("r", "&", 2);
     $d->setOperant("r", "OR", 2);
     $d->setValue("published", true, 2);
    }

    $d->setValue("show_total", $this->config["listitems"]);
   }
   else //tags cloud
   {
    $d=Data::cache("blog_tags", "view", "all");
    $d->clearValues();
    $d->sortOrder("tag+");

    if($this->config["listcatnr"])
     $d->setValue("catnr", $this->config["listcatnr"]);

    $d->field["cloud_size"]["min"]=1;
    $d->field["cloud_size"]["max"]=10;
    $d->field["cloud_size"]["type"]="nr";
   }

   if($_benchmark) $_benchmark->stop("Data object");

   return $d;
  }


  function cache(&$cacheTime, &$cacheKey)
  {
   //no caching on comment error or search
   if($this->commentError||request("search"))
    return false;

   return parent::cache($cacheTime, $cacheKey);
  }

  function _cacheTemplateUpdated(&$cacheTime, &$dc)
  {
   global $_path;

   if($this->config["listtype"]=="Item"||$this->config["listtype"]=="Blog") //item/list template
    return parent::_cacheTemplateUpdated($cacheTime, $dc); //use lister plugin
   else if($this->config["listtype"]=="Latest posts") //Latest posts
   {
    if($this->config["templatelist"])
     $time=FS::getTimeS($_path["project"]["templates"].$this->config["templatelist"], "modified");
    else
     $time=FS::getTimeS($this->plugin->path["templates"].$this->plugin->templatelatestposts, "modified");
   }
   else if($this->config["listtype"]=="Latest comments") //Latest comments
   {
    if($this->config["templatelist"])
     $time=FS::getTimeS($_path["project"]["templates"].$this->config["templatelist"], "modified");
    else
     $time=FS::getTimeS($this->plugin->path["templates"].$this->plugin->templatelatestcomments, "modified");
   }
   else //tag cloud templates
   {
    if($this->config["templatelist"])
     $time=FS::getTimeS($_path["project"]["templates"].$this->config["templatelist"], "modified");
    else
     $time=FS::getTimeS($this->plugin->path["templates"].$this->plugin->templatecloud, "modified");
   }

   if($cacheTime<$time)
    $cacheTime=$time;

   return true;
  }


  function output()
  {
   global $_path, $_config, $_benchmark;

   if($_benchmark) $_benchmark->start("Get content");

   if(!($d=$this->_getData()))
    return false;

   $id=$d->getID();

   if($this->config["cmspage"]||($this->config["blogpage"]))
   {
    $tmp=Data::cache("pager_categories", "view", "item");

    if($this->config["cmspage"])
    {
     $tmp->setValue("nr", $this->config["cmspagenr"]);
     $tmp->setShowFields("urlname");

     if($tmp->get()&&$tmp->next())
      $cmspage=$tmp->v["urlname"];
     else
      $cmspage=$this->config["cmspagenr"];
    }

    if($this->config["blogpage"])
    {
     $tmp->setValue("nr", $this->config["blogpagenr"]);
     $tmp->setShowFields("urlname");

     if($tmp->get()&&$tmp->next())
      $blogpage=$tmp->v["urlname"];
     else
      $blogpage=$this->config["blogpagenr"];
    }

    unset($tmp);
   }

   $d->addField("sort_order", "text", "show", "control", false, false, implode(",", $d->sortOrder));

   $d->addField("item_url", "text", "", "control", 0);
   if($_config->get("prettyurls")) //mod rewrite
   {
    if($this->config["cmspage"])
     $d->addField("cms_url", "text", "", "control", 0, false, $_path["HTML"]["current"].$cmspage."/");
    else
     $d->addField("cms_url", "text", "", "control", 0);

    $d->addField("base_url", "text", "", "control", 0, false, $_path["HTML"]["current"]);
    $d->addField("root_url", "text", "", "control", 0, false, $_path["root"]);

    $tmp=$_path["HTML"]["current"];
    foreach($this->plugin->vars as $k => $v)
     if($k=="p"||substr($k, 0, 2)=="p[")
      $tmp.=$v."/";

    $d->addField("page_url", "text", "", "control", 0, false, $tmp);

    if($this->config["blogpage"])
     $d->addField("blog_url", "text", "", "control", 0, false, $_path["HTML"]["current"].$blogpage."/");
    else //no specific blog page, use current page
     $d->addField("blog_url", "text", "", "control", 0, false, $tmp);

    unset($tmp);
   }
   else
   {
    if($this->config["cmspage"])
     $d->addField("cms_url", "text", "", "control", 0, false, $_path["HTML"]["current"].htmlentities("?=".$cmspage."&"));
    else
     $d->addField("cms_url", "text", "", "control", 0);

    if($this->config["blogpage"])
     $d->addField("blog_url", "text", "", "control", 0, false, $_path["HTML"]["current"].htmlentities("?=".$blogpage."&"));
    else //no specific blog page, use current page
     $d->addField("blog_url", "text", "", "control", 0, false, htmlentities($this->plugin->url()));

    $d->addField("base_url", "text", "", "control", 0, false, "");
    $d->addField("root_url", "text", "", "control", 0, false, $_path["root"]);
    $d->addField("page_url", "text", "", "control", 0, false, htmlentities($this->plugin->url()));
   }

   //get comments category + rights
   if($this->config["listtype"]=="Blog"||$this->config["listtype"]=="Item")
   {
    $dtmp=Data::cache("categories", "view", "all");
    $dtmp->setShowFields("nr");
    $dtmp->clearValues();

    $dtmp->setValue("catnr", $this->config["listcatnr"]);
    $dtmp->setValue("text", "BLOG COMMENTS CONTAINER");
    $dtmp->setValue("show_total", 1);

    if(!$dtmp->get()||!$dtmp->next()) //can't get comments category, either no rights or setup needs to be rerun (BLOG COMMENTS CONTAINER in blog category should exist)
    {
     $d->addField("comment_catnr", "nr", "", "control", 0, false, false);
     $d->addField("comment_rights", "boolean", "", "control", false, false, false);
     $d->addField("comment_captcha", "boolean", "", "control", false, false, false);
    }
    else
    {
     $d->addField("comment_catnr", "nr", "", "control", 0, false, $dtmp->v["nr"]);

     if($dtmp->r("add", "content"))
     {
      $d->addField("comment_rights", "boolean", "", "control", false, false, true);

      if($_config->userAnonymous())
       $d->addField("comment_captcha", "boolean", "", "control", false, false, true);
      else
       $d->addField("comment_captcha", "boolean", "", "control", false, false, false);
     }
     else
     {
      $d->addField("comment_rights", "boolean", "", "control", false, false, false);
      $d->addField("comment_captcha", "boolean", "", "control", false, false, false);
     }
    }
   }

   //comment submit items
   $d->addField("comment_text", "text", "", "control", 0, false, "");
   $d->addField("comment_error", "text", "", "control", 0, false, "");

   //load template
   if($this->config["listtype"]=="Item") //item template
   {
    if($this->config["templateitem"])
     $templateFile=$_path["project"]["templates"].$this->config["templateitem"];
    else
     $templateFile=$this->plugin->path["templates"].$this->plugin->templateitem;
   }
   else if($this->config["listtype"]=="Blog") //list template
   {
    if($this->config["templatelist"])
     $templateFile=$_path["project"]["templates"].$this->config["templatelist"];
    else
     $templateFile=$this->plugin->path["templates"].$this->plugin->templatelist;
   }
   else if($this->config["listtype"]=="Latest posts") //Latest posts
   {
    if($this->config["templatelist"])
     $templateFile=$_path["project"]["templates"].$this->config["templatelist"];
    else
     $templateFile=$this->plugin->path["templates"].$this->plugin->templatelatestposts;
   }
   else if($this->config["listtype"]=="Latest comments") //Latest comments
   {
    if($this->config["templatelist"])
     $templateFile=$_path["project"]["templates"].$this->config["templatelist"];
    else
     $templateFile=$this->plugin->path["templates"].$this->plugin->templatelatestcomments;
   }
   else //tag cloud templates
   {
    if($this->config["templatelist"])
     $templateFile=$_path["project"]["templates"].$this->config["templatelist"];
    else
     $templateFile=$this->plugin->path["templates"].$this->plugin->templatecloud;
   }

   if($_benchmark) $_benchmark->start("Template");

   $template=new Format_Template(true);

   if(!$template->read($templateFile)||!$template->analyze($d))
   {
    $this->e->add($template->e);
    return false;
   }

   if($template->markerExists("_fields")&&$this->config["showfields"]) //_fields marker in template and predefined fields set
    $d->setShowFields(array_merge($this->config["showfields"], $d->check("use", "show"))); //added predefined fields to show fields
   //else //use template defined fields

   if($_benchmark) $_benchmark->stop("Template");

   if($_benchmark) $_benchmark->start("Get data");

   //get data
   if($this->config["pagebrowser"]||$template->showCount())
    $success=$d->get($template->getLevel(), true);
   else
    $success=$d->get($template->getLevel());

   if(!$success)
   {
    $this->e->add($d->e);
    return false;
   }

   //set sort_order, page_url, base_url, root_url and item_url values
   for($c=0;$c<$d->vmax;$c++)
   {
    if($this->config["listtype"]=="Blog"||$this->config["listtype"]=="Item")
    {
     $d->setDefaultValue("comment_catnr", $c);
     $d->setDefaultValue("comment_rights", $c);
    }

    if($this->commentError&&$d->getValue("nr", $c)==$this->commentEntry)
    {
     $d->setValue("comment_text", $this->commentText, $c);
     $d->setValue("comment_error", $this->commentError, $c);
    }
    else
    {
     $d->setDefaultValue("comment_text", $c);
     $d->setDefaultValue("comment_error", $c);
    }

    $d->setDefaultValue("sort_order", $c);
    $d->setDefaultValue("page_url", $c);
    $d->setDefaultValue("base_url", $c);
    $d->setDefaultValue("root_url", $c);
    $d->setDefaultValue("cms_url", $c);

    if($_config->get("prettyurls")) //mod rewrite
     $d->setValue("item_url", $d->getValue("page_url", $c).$d->getValue($id, $c)."/", $c);
    else
     $d->setValue("item_url", $d->getValue("page_url", $c).htmlentities($id."=".$d->getValue($id, $c)."&"), $c);
   }

   if($_benchmark) $_benchmark->stop("Get data");
   if($_benchmark) $_benchmark->start("Populate template");

   if($d->e->any("fatal"))
   {
    $this->e->add($d->e);
    return false;
   }

   if(!$template->populate())
   {
    $this->e->add($template->e);
    return false;
   }

   $output=$template->output();

   if($_benchmark) $_benchmark->stop("Populate template");

   if($this->config["pagebrowser"]&&$d->extra!="item")
   {
    if($_benchmark) $_benchmark->start("Page browser");

    $templatepagebrowser=new Format_Template(true);

    if($this->config["templatepagebrowser"])
     $templatepagebrowser->read($_path["project"]["templates"].$this->config["templatepagebrowser"]);

    if($templatepagebrowser->pageBrowser($d, $_path["HTML"]["url"], (request("sort")?true:false), false))
     $output.=$templatepagebrowser->output();
    else
    {
     $this->e->add($templatepagebrowser->e);
     return false;
    }

    if($_benchmark) $_benchmark->stop("Page browser");
   }

   if($_benchmark) $_benchmark->stop("Get content");

   return $output;
  }

 }
?>
