<?

 /*************************************************************************************
 * Filename: modules/pluginConfigs.php
 *
 * This file is part of the Blog JAS plugin.
 * Copyright 2003-2016 by Matthijs Schuurman
 *
 * The Blog JAS plugin is free software under the terms of the
 * GNU General Public License version 3 or any later version.
 *
 * For information about the license please refer to:
 * LICENSE.txt in the root of the plugin or http://jas.junerules.com/plugins/blog/
 *************************************************************************************/


 require_once($_path["include"]."module.php");

 class Plugin_Module_blog_pluginConfigs extends Module
 {
  function __construct(&$data)
  {
   parent::__construct($data);

   if($this->data->module!="pluginConfigs")
    $this->extend("pluginConfigs");

   $this->data->title="Blog plugin configuration";

   $this->data->addField("listtype", "enum", "all", "reload", false, false, "Blog", "Show");
   $this->data->enumOptions("listtype", "Blog", "Latest posts", "Latest comments", "Tag cloud");

   $this->data->addField("listcatnr", "nr", "all", "", false, false, 0, "List category");
   $this->data->addReference("listcatnr", "categories", "nr", "*:0");

   $this->data->addField("blogpage", "boolean", "all", "reload", false, false, false, "Use blog page");
   $this->data->addField("blogpagenr", "nr", "all", "", false, false, false, "Blog page");
   $this->data->addReference("blogpagenr", "categories", "nr", "*:0");

   $this->data->addField("cmspage", "boolean", "all", "reload", false, false, false, "Use CMS page");
   $this->data->addField("cmspagenr", "nr", "all", "", false, false, false, "CMS page");
   $this->data->addReference("cmspagenr", "categories", "nr", "*:0");

   $this->data->addField("pagebrowser", "boolean", "all", "reload", false, false, false, "Show page browser");
   $this->data->addField("listitems", "nr", "all", "", 0, 100, 10, "Number of blog entries");
   $this->data->addField("templatepagebrowser", "localfile", "all", "recursive", false, 255, "", "Alternative page browser template");

   $this->data->addField("templateitem", "localfile", "all", "recursive", false, 255, "", "Item template");
   $this->data->addField("templatelist", "localfile", "all", "recursive", false, 255, "", "List template");

   $this->data->group("Show", "listtype", "listcatnr", "blogpage", "blogpagenr", "cmspage", "cmspagenr");
   $this->data->group("Page browser", "pagebrowser", "listitems", "templatepagebrowser");
   $this->data->group("Alternative templates", "templateitem", "templatelist");
  }

  function postInit()
  {
   global $_path;

   $this->data->setFileDir("templatepagebrowser", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatepagebrowser", "html", "htm");
   $this->data->setFileDir("templateitem", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templateitem", "html", "htm");
   $this->data->setFileDir("templatelist", $_path["project"]["templates"]);
   $this->data->setFileExtensions("templatelist", "html", "htm");

   return $this->customizeFields();
  }
  function copyPostGet(){return $this->customizeFields();}
  function editPostGet(){return $this->customizeFields();}
  function movePostGet(){return $this->customizeFields();}
  function deletePostGet(){return $this->customizeFields();}

  function customizeFields()
  {
   if($this->data->getValue("listtype")=="Blog")
   {
    $this->data->field["blogpage"]["properties"].=";hidden";
    $this->data->field["blogpagenr"]["properties"].=";hidden";

    $this->data->resetField("cmspage");

    if($this->data->getValue("cmspage"))
     $this->data->resetField("cmspagenr");
    else
     $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->resetField("listitems");

    $this->data->resetField("pagebrowser");

    if(!$this->data->getValue("pagebrowser"))
    {
     $this->data->field["templatepagebrowser"]["properties"].=";hidden";

     //move listitems to List group
     $this->data->field["listitems"]["min"]=0;
     $this->data->field["listitems"]["defaultvalue"]=0;
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Show");

     $this->data->field["listitems"]["title"]="Number of blog entries";
    }
    else
    {
     $this->data->resetField("templatepagebrowser");

     $this->data->resetField("listitems");
     $this->data->field["listitems"]["group"]=$this->data->getGroupID("Page browser");
     $this->data->field["listitems"]["title"]="Items per page";
    }

    $this->data->resetField("templateitem");
    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="List template";
   }
   else if($this->data->getValue("listtype")=="Latest posts"||$this->data->getValue("listtype")=="Latest comments")
   {
    $this->data->resetField("blogpage");

    if($this->data->getValue("blogpage"))
     $this->data->resetField("blogpagenr");
    else
     $this->data->field["blogpagenr"]["properties"].=";hidden";


    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";

    $this->data->resetField("listitems");

    //move listitems to List group
    $this->data->field["listitems"]["min"]=1;
    $this->data->field["listitems"]["defaultvalue"]=5;
    $this->data->field["listitems"]["group"]=$this->data->getGroupID("Show");

    if($this->data->getValue("listtype")=="Latest posts")
     $this->data->field["listitems"]["title"]="Number of blog entries";
    else //Latest comments
     $this->data->field["listitems"]["title"]="Number of comments";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";

    $this->data->field["templateitem"]["properties"].=";hidden";

    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="Latest template";
   }
   else //tags cloud
   {
    $this->data->resetField("blogpage");

    if($this->data->getValue("blogpage"))
     $this->data->resetField("blogpagenr");
    else
     $this->data->field["blogpagenr"]["properties"].=";hidden";


    $this->data->field["cmspage"]["properties"].=";hidden";
    $this->data->field["cmspagenr"]["properties"].=";hidden";
    
    $this->data->field["listitems"]["properties"].=";hidden";

    $this->data->field["pagebrowser"]["properties"].=";hidden";
    $this->data->field["templatepagebrowser"]["properties"].=";hidden";

    $this->data->field["templateitem"]["properties"].=";hidden";

    $this->data->resetField("templatelist");
    $this->data->field["templatelist"]["title"]="Cloud template";
   }

   return true;
  }

 }
?>
